@@ -566,7 +566,7 @@ public class FileItemService implements IFileItemService {
      *
      */
     public void shutdown() {
-        if (m_terminated.compareAndSet(false, true)) {
+        if (m_running.compareAndSet(true, false)) {
             if (null != m_fileStoreRemover) {
                 m_fileStoreRemover.shutdown();
             }
@@ -692,5 +692,5 @@ public class FileItemService implements IFileItemService {
 
     protected int m_curFileStorePos = -1;
 
-    protected AtomicBoolean m_terminated = new AtomicBoolean(false);
+    protected AtomicBoolean m_running = new AtomicBoolean(true);
 }
