@@ -262,7 +262,7 @@ public class FileItemUtils {
         @NonNull Properties properties, @NonNull String combineString, final String... appendStrings) {
 
         final Set<Object> keySet = properties.keySet();
-        final StringBuilder sql = new StringBuilder(startString);
+        final StringBuilder sql = new StringBuilder(256 + startString.length()).append(startString);
         boolean following = false;
 
         for(final Object curKey : keySet) {
