@@ -135,9 +135,9 @@ public class ImageConverterServerRest extends JAXRSService {
     public String status(@QueryParam("metrics") @DefaultValue("false") String metrics) {
         LOG.trace("IC WebService received #status request");
 
-        return implCreateImageConverterServerHtmlPage(m_terminated.get() ?
-            OX_IMAGECONVERTER_SERVER_TERMINATED_RESPONSE_TEXT :
-                OX_IMAGECONVERTER_SERVER_DEFAULT_RESPONSE_TEXT,
+        return implCreateImageConverterServerHtmlPage(m_running.get() ?
+            OX_IMAGECONVERTER_SERVER_DEFAULT_RESPONSE_TEXT :
+                OX_IMAGECONVERTER_SERVER_TERMINATED_RESPONSE_TEXT,
             StringUtils.equalsIgnoreCase(metrics, "true") ?
                 ImageConverterUtils.IC_MONITORING :
                     null);
@@ -162,7 +162,7 @@ public class ImageConverterServerRest extends JAXRSService {
 
         ResponseBuilder responseBuilder = null;
 
-        if (!m_terminated.get()) {
+        if (m_running.get()) {
             try (final InputStream inputStm = m_imageConverter.getImage(imageKey, requestFormat, context)) {
                 responseBuilder = implCreateFileResponse(inputStm);
             } catch (Exception e) {
@@ -192,7 +192,7 @@ public class ImageConverterServerRest extends JAXRSService {
 
         ResponseBuilder responseBuilder = null;
 
-        if (!m_terminated.get()) {
+        if (m_running.get()) {
             try {
                 final IMetadata metadata = m_imageConverter.getMetadata(imageKey, context);
 
@@ -227,7 +227,7 @@ public class ImageConverterServerRest extends JAXRSService {
 
         ResponseBuilder responseBuilder = null;
 
-        if (!m_terminated.get()) {
+        if (m_running.get()) {
             try (final MetadataImage metadataImage = m_imageConverter.getImageAndMetadata(imageKey, requestFormat, context)) {
                 responseBuilder = implCreateMetadataImageResponse(metadataImage);
             } catch (Exception e) {
@@ -257,7 +257,7 @@ public class ImageConverterServerRest extends JAXRSService {
 
         ResponseBuilder responseBuilder = null;
 
-        if (!m_terminated.get()) {
+        if (m_running.get()) {
             try (final InputStream inputStm = implGetInputStream(multiPart)) {
                 if (null != inputStm) {
                     m_imageConverter.cacheImage(imageKey, inputStm, context);
@@ -296,7 +296,7 @@ public class ImageConverterServerRest extends JAXRSService {
 
         ResponseBuilder responseBuilder = null;
 
-        if (!m_terminated.get()) {
+        if (m_running.get()) {
             try (final InputStream inputStm = implGetInputStream(multiPart)) {
                 if (null != inputStm) {
                     try (final InputStream resultInputStm = m_imageConverter.cacheAndGetImage(imageKey, requestFormat, inputStm, context)) {
@@ -336,7 +336,7 @@ public class ImageConverterServerRest extends JAXRSService {
 
         ResponseBuilder responseBuilder = null;
 
-        if (!m_terminated.get()) {
+        if (m_running.get()) {
             try (final InputStream sourceImageInputStream = implGetInputStream(multiPart)) {
                 if (null != sourceImageInputStream) {
                     try (final MetadataImage metadaImage = m_imageConverter.cacheAndGetImageAndMetadata(imageKey, requestFormat, sourceImageInputStream, context)) {
@@ -366,7 +366,7 @@ public class ImageConverterServerRest extends JAXRSService {
 
         LOG.trace("IC WebService received #clearImages request");
 
-        if (!m_terminated.get()) {
+        if (m_running.get()) {
             try {
                 if (isEmpty(context)) {
                     m_imageConverter.clearImages();
@@ -397,7 +397,7 @@ public class ImageConverterServerRest extends JAXRSService {
 
         LOG.trace("IC WebService received #clearImagesByKey request: {}", imageKey);
 
-        if (!m_terminated.get()) {
+        if (m_running.get()) {
             try {
                 m_imageConverter.clearImagesByKey(imageKey);
                 responseBuilder = implCreateSuccessResponse();
@@ -424,7 +424,7 @@ public class ImageConverterServerRest extends JAXRSService {
 
         LOG.trace("IC WebService received #getKeyCount request");
 
-        if (!m_terminated.get()) {
+        if (m_running.get()) {
             try {
                 ret.put("count", m_imageConverter.getKeyCount(context));
             } catch (Exception e) {
@@ -452,7 +452,7 @@ public class ImageConverterServerRest extends JAXRSService {
     public JSONObject getKeys(@QueryParam("context") @DefaultValue("") String context) {
         JSONObject ret = new JSONObject();
 
-        if (!m_terminated.get()) {
+        if (m_running.get()) {
             LOG.trace("IC WebService received #getKey request");
 
             try {
@@ -475,7 +475,7 @@ public class ImageConverterServerRest extends JAXRSService {
      *
      */
     public void shutdown() {
-        if (m_terminated.compareAndSet(false, true)) {
+        if (m_running.compareAndSet(true, false)) {
             LOG.trace("ImageConverter server shutdown finished");
         }
     }
@@ -487,7 +487,7 @@ public class ImageConverterServerRest extends JAXRSService {
      * @return
      */
     private static String implCreateImageConverterServerHtmlPage(final String[] content, @Nullable final IImageConverterMonitoring monitoring) {
-        final StringBuilder htmlBuilder = new StringBuilder();
+        final StringBuilder htmlBuilder = new StringBuilder(256);
 
         htmlBuilder.append("<html>").
             append("<head><meta charset=\"UTF-8\"><title>").append(OX_IMAGECONVERTER_SERVER_TITLE).append("</title></head>").
@@ -517,7 +517,7 @@ public class ImageConverterServerRest extends JAXRSService {
                         final boolean isRatioMetric = metricsPropertyName.endsWith("Ratio");
 
                         try {
-                            final String numberString = new StringBuilder().append(method.invoke(monitoring)).toString();
+                            final String numberString = new StringBuilder(256).append(method.invoke(monitoring)).toString();
 
                             if (NumberUtils.isNumber(numberString)) {
                                 htmlBuilder.append("<p>").append(metricsPropertyName).append(": ");
@@ -705,5 +705,5 @@ public class ImageConverterServerRest extends JAXRSService {
 
     final private  IImageConverter m_imageConverter;
 
-    final private AtomicBoolean m_terminated = new AtomicBoolean(false);
+    final private AtomicBoolean m_running = new AtomicBoolean(true);
 }
