@@ -124,11 +124,12 @@ public final class ImageConverter implements IImageConverter {
         }
 
         // create and start worker queue to perform the image transformations (either synchronously or asynchrnously)
-        (m_imageConversionQueue = new ImageConverterQueue(this, m_fileItemService, metadataReader)).start();
+        (m_queue = new ImageConverterQueue(this, m_fileItemService, metadataReader)).start();
 
         // finally trace list of used image formats
         if (LOG.isInfoEnabled()) {
-            final StringBuilder infoStr = new StringBuilder("IC ImageConverter is using the following target formats:\n");
+            final StringBuilder infoStr = ImageConverterUtils.STR_BUILDER().
+                append("IC ImageConverter is using the following target formats:\n");
 
             for (final ImageFormat curImageFormat : m_imageFormats) {
                 infoStr.append("\tIC ").append(curImageFormat.toString()).append('\n');
@@ -147,25 +148,18 @@ public final class ImageConverter implements IImageConverter {
      *
      */
     public void shutdown() {
-        if (m_terminated.compareAndSet(false, true)) {
+        if (m_running.compareAndSet(true, false)) {
             final long shutdownStartTimeMillis = System.currentTimeMillis();
 
             LOG.info("IC starting shutdown");
 
             m_keyManager.shutdown();
-            m_imageConversionQueue.shutdown();
+            m_queue.shutdown();
 
             LOG.info("IC shutdown finished in {}ms", (System.currentTimeMillis() - shutdownStartTimeMillis));
         }
     }
 
-    /**
-     * @return
-     */
-    public boolean isTerminated() {
-        return m_terminated.get();
-    }
-
     // - IImageConverter ----------------------------------------------------------
 
     /*
@@ -177,16 +171,19 @@ public final class ImageConverter implements IImageConverter {
     public InputStream getImage(final String imageKey, final String requestFormat, final String... context) throws ImageConverterException {
         final long requestStartTime = System.currentTimeMillis();
 
-        implTrace(new StringBuilder("IC #getImage called (imageKey / requestFormat): ").
-            append(imageKey).append(" / ").append(requestFormat).toString(),
-            context);
+        if (LOG.isTraceEnabled()) {
+            implTrace(ImageConverterUtils.STR_BUILDER().
+                append("IC #getImage called (imageKey / requestFormat): ").
+                append(imageKey).append(" / ").append(requestFormat).toString(),
+                context);
+        }
 
         ImageConverterStatus status = (isNotEmpty(imageKey) && isNotEmpty(requestFormat)) ?
             ImageConverterStatus.OK :
                 ImageConverterStatus.KEY_NOT_VALID;
 
 
-        try (final MetadataImage metadataImage = m_imageConversionQueue.getMetadataImage(imageKey, requestFormat, implGetContext(context))) {
+        try (final MetadataImage metadataImage = m_queue.getMetadataImage(imageKey, requestFormat)) {
             InputStream ret = (null != metadataImage) ?
                 metadataImage.getImageInputStream(true) :
                     null;
@@ -213,9 +210,12 @@ public final class ImageConverter implements IImageConverter {
     public IMetadata getMetadata(String imageKey, String... context) throws ImageConverterException {
         final long requestStartTime = System.currentTimeMillis();
 
-        implTrace(new StringBuilder("IC #getMetadata called (imageKey / requestFormat): ").
-            append(imageKey).toString(),
-            context);
+        if (LOG.isTraceEnabled()) {
+            implTrace(ImageConverterUtils.STR_BUILDER().
+                append("IC #getMetadata called (imageKey / requestFormat): ").
+                append(imageKey).toString(),
+                context);
+        }
 
         ImageConverterStatus status = isNotEmpty(imageKey) ?
             ImageConverterStatus.OK :
@@ -223,7 +223,7 @@ public final class ImageConverter implements IImageConverter {
 
         try {
             final IMetadata ret = (ImageConverterStatus.OK == status) ?
-                m_imageConversionQueue.getMetadata(imageKey, implGetContext(context)) :
+                m_queue.getMetadata(imageKey) :
                     null;
 
             if (null == ret) {
@@ -248,9 +248,12 @@ public final class ImageConverter implements IImageConverter {
     public MetadataImage getImageAndMetadata(String imageKey, String requestFormat, String... context) throws ImageConverterException {
         final long requestStartTime = System.currentTimeMillis();
 
-        implTrace(new StringBuilder("IC #getImageAndMetadata called (imageKey / requestFormat): ").
-            append(imageKey).append(" / ").append(requestFormat).toString(),
-            context);
+        if (LOG.isTraceEnabled()) {
+            implTrace(ImageConverterUtils.STR_BUILDER().
+                append("IC #getImageAndMetadata called (imageKey / requestFormat): ").
+                append(imageKey).append(" / ").append(requestFormat).toString(),
+                context);
+        }
 
         ImageConverterStatus status = isNotEmpty(imageKey) ?
             ImageConverterStatus.OK :
@@ -258,7 +261,7 @@ public final class ImageConverter implements IImageConverter {
 
         try {
             final MetadataImage ret = (ImageConverterStatus.OK == status) ?
-                m_imageConversionQueue.getMetadataImage(imageKey, requestFormat, implGetContext(context)) :
+                m_queue.getMetadataImage(imageKey, requestFormat) :
                     null;
 
             if (null == ret) {
@@ -285,7 +288,9 @@ public final class ImageConverter implements IImageConverter {
     public void cacheImage(final String imageKey, final InputStream srcImageStm, final String... context) throws ImageConverterException {
         final long requestStartTime = System.currentTimeMillis();
 
-        implTrace("IC #cacheImage called for imageKey: " + imageKey, context);
+        if (LOG.isTraceEnabled()) {
+            implTrace("IC #cacheImage called for imageKey: " + imageKey, context);
+        }
 
         ImageConverterStatus status = (isNotEmpty(imageKey) && (null != srcImageStm)) ?
             ImageConverterStatus.OK :
@@ -293,7 +298,7 @@ public final class ImageConverter implements IImageConverter {
 
         try {
             if (ImageConverterStatus.OK == status) {
-                m_imageConversionQueue.cache(imageKey, srcImageStm, implGetContext(context), null);
+                m_queue.cache(imageKey, srcImageStm, implGetContext(context), null);
             }
         } catch (ImageConverterException e) {
             LOG.trace("IC exception while caching Image", e);
@@ -314,9 +319,12 @@ public final class ImageConverter implements IImageConverter {
     public InputStream cacheAndGetImage(final String imageKey, final String requestFormat, final InputStream srcImageStm, final String... context) throws ImageConverterException {
         final long requestStartTime = System.currentTimeMillis();
 
-        implTrace(new StringBuilder("IC #cacheAndGetImage called (imageKey / requestFormat): ").
-            append(imageKey).append(" / ").append(requestFormat).toString(),
-            context);
+        if (LOG.isTraceEnabled()) {
+            implTrace(ImageConverterUtils.STR_BUILDER().
+                append("IC #cacheAndGetImage called (imageKey / requestFormat): ").
+                append(imageKey).append(" / ").append(requestFormat).toString(),
+                context);
+        }
 
         ImageConverterStatus status = isNotEmpty(imageKey) ?
             ImageConverterStatus.OK :
@@ -324,12 +332,10 @@ public final class ImageConverter implements IImageConverter {
 
         try {
             if (ImageConverterStatus.OK == status) {
-                final String usedContext = implGetContext(context);
-
                 try (final MetadataImage metadataImage = (null != srcImageStm) ?
-                    m_imageConversionQueue.cacheAndGetMetadataImage(imageKey, srcImageStm, requestFormat, usedContext, null) :
+                    m_queue.cacheAndGetMetadataImage(imageKey, srcImageStm, requestFormat, implGetContext(context), null) :
                         (isNotEmpty(requestFormat) ?
-                            m_imageConversionQueue.getMetadataImage(imageKey, requestFormat, usedContext) :
+                            m_queue.getMetadataImage(imageKey, requestFormat) :
                                 null)) {
 
                     InputStream ret = (null != metadataImage) ?
@@ -362,9 +368,12 @@ public final class ImageConverter implements IImageConverter {
     public MetadataImage cacheAndGetImageAndMetadata(String imageKey, String requestFormat, InputStream srcImageStm, String... context) throws ImageConverterException {
         final long requestStartTime = System.currentTimeMillis();
 
-        implTrace(new StringBuilder("IC #cacheAndGetImageAndMetadata called (imageKey / requestFormat): ").
-            append(imageKey).append(" / ").append(requestFormat).toString(),
-            context);
+        if (LOG.isTraceEnabled()) {
+            implTrace(ImageConverterUtils.STR_BUILDER().
+                append("IC #cacheAndGetImageAndMetadata called (imageKey / requestFormat): ").
+                append(imageKey).append(" / ").append(requestFormat).toString(),
+                context);
+        }
 
         ImageConverterStatus status = isNotEmpty(imageKey) ?
             (((null != srcImageStm) || isNotEmpty(requestFormat)) ? ImageConverterStatus.OK : ImageConverterStatus.KEY_NOT_AVAILABLE) :
@@ -372,11 +381,9 @@ public final class ImageConverter implements IImageConverter {
 
         try {
             if (ImageConverterStatus.OK == status) {
-                final String usedContext = implGetContext(context);
-
                 return (null != srcImageStm) ?
-                    m_imageConversionQueue.cacheAndGetMetadataImage(imageKey, srcImageStm, requestFormat, usedContext, null) :
-                        m_imageConversionQueue.getMetadataImage(imageKey, requestFormat, usedContext);
+                    m_queue.cacheAndGetMetadataImage(imageKey, srcImageStm, requestFormat, implGetContext(context), null) :
+                        m_queue.getMetadataImage(imageKey, requestFormat);
             }
         } catch (ImageConverterException e) {
             LOG.trace("IC exception while caching and getting ImageAndMetadata", e);
@@ -399,12 +406,14 @@ public final class ImageConverter implements IImageConverter {
     public void clearImages(final String... context) throws ImageConverterException {
         final long requestStartTime = System.currentTimeMillis();
 
-        implTrace("IC #clearImages called", context);
+        if (LOG.isTraceEnabled()) {
+            implTrace("IC #clearImages called", context);
+        }
 
         ImageConverterStatus status = ImageConverterStatus.OK;
 
         try {
-            remove(getAvailable(implCreateContextProperties(context)));
+            remove(Arrays.asList(getAvailable(implCreateContextProperties(context))));
         } catch (ImageConverterException e) {
             LOG.trace("IC exception while clearing Images", e);
 
@@ -424,7 +433,9 @@ public final class ImageConverter implements IImageConverter {
     public void clearImagesByKey(String imageKey) throws ImageConverterException {
         final long requestStartTime = System.currentTimeMillis();
 
-        implTrace("IC #clearImagesByKey called for imageKey: " + imageKey);
+        if (LOG.isTraceEnabled()) {
+            implTrace("IC #clearImagesByKey called for imageKey: " + imageKey);
+        }
 
         ImageConverterStatus status = isNotEmpty(imageKey) ?
             ImageConverterStatus.OK :
@@ -453,7 +464,9 @@ public final class ImageConverter implements IImageConverter {
     public long getKeyCount(final String... context) throws ImageConverterException {
         final long requestStartTime = System.currentTimeMillis();
 
-        implTrace("IC #getKeyCount called", context);
+        if (LOG.isTraceEnabled()) {
+            implTrace("IC #getKeyCount called", context);
+        }
 
         ImageConverterStatus status = ImageConverterStatus.OK;
 
@@ -480,7 +493,9 @@ public final class ImageConverter implements IImageConverter {
     public String[] getKeys(final String... context) throws ImageConverterException {
         final long requestStartTime = System.currentTimeMillis();
 
-        implTrace("IC #getKeys called", context);
+        if (LOG.isTraceEnabled()) {
+            implTrace("IC #getKeys called", context);
+        }
 
         ImageConverterStatus status = ImageConverterStatus.OK;
 
@@ -505,7 +520,9 @@ public final class ImageConverter implements IImageConverter {
     public long getTotalImagesSize(final String... context) throws ImageConverterException {
         final long requestStartTime = System.currentTimeMillis();
 
-        implTrace("IC #getTotalImagesSize called", context);
+        if (LOG.isTraceEnabled()) {
+            implTrace("IC #getTotalImagesSize called", context);
+        }
 
         ImageConverterStatus status = ImageConverterStatus.OK;
 
@@ -639,35 +656,19 @@ public final class ImageConverter implements IImageConverter {
      * @return
      */
     void remove(@NonNull final String imageKey) throws ImageConverterException {
-        ElementLocker.lock(imageKey, ElementLock.LockMode.WAIT_IF_PROCESSED);
+        // instantly move job to the highest priority queue,
+        // since the current request needs to be handled ASAP
+        if (m_running.get()) {
+            m_queue.removeImageConverterJob(imageKey);
 
-        try {
-            m_fileItemService.removeSubGroup(ImageConverterUtils.IMAGECONVERTER_GROUPID, imageKey);
-        } catch (FileItemException e) {
-            throw new ImageConverterException("IC error while removing image key: " + imageKey, e);
-        } finally {
-            ElementLocker.unlock(imageKey);
-        }
-    }
+            ElementLocker.lock(imageKey, ElementLock.LockMode.WAIT_IF_PROCESSED);
 
-    /**
-     * @param imageKeys
-     * @throws ImageConverterException
-     */
-    void remove(final String[] imageKeys) throws ImageConverterException {
-        if (isNotEmpty(imageKeys) && !isTerminated()) {
-            final String[] targetImageKeys = Arrays.asList(imageKeys).stream().
-                filter(p -> ElementLocker.lock(p, ElementLock.LockMode.TRY_LOCK)).
-                toArray(p -> new String[p]);
-
-            if (isNotEmpty(targetImageKeys)) {
-                try {
-                    m_fileItemService.removeSubGroups(ImageConverterUtils.IMAGECONVERTER_GROUPID, targetImageKeys);
-                } catch (FileItemException e) {
-                    throw new ImageConverterException("IC error while removing image " + targetImageKeys.length + " keys", e);
-                } finally {
-                    Arrays.asList(targetImageKeys).forEach(p -> ElementLocker.unlock(p));
-                }
+            try {
+                m_fileItemService.removeSubGroup(ImageConverterUtils.IMAGECONVERTER_GROUPID, imageKey);
+            } catch (FileItemException e) {
+                throw new ImageConverterException("IC error while removing image key: " + imageKey, e);
+            } finally {
+                ElementLocker.unlock(imageKey, ElementLock.UnlockMode.STANDARD);
             }
         }
     }
@@ -677,10 +678,14 @@ public final class ImageConverter implements IImageConverter {
      * @throws ImageConverterException
      */
     void remove(@NonNull final Collection<String> imageKeysCollection) throws ImageConverterException {
-        if (!imageKeysCollection.isEmpty() && !isTerminated()) {
+        if (!imageKeysCollection.isEmpty() && m_running.get()) {
+            // remove all queued entries first
+             imageKeysCollection.forEach((imageKey) -> m_queue.removeImageConverterJob(imageKey));
+
+            // try locking all given imageKeys and remove persistent data of locked keys
             final String[] targetImageKeys = imageKeysCollection.stream().
-                filter(p -> ElementLocker.lock(p, ElementLock.LockMode.TRY_LOCK)).
-                toArray(p -> new String[p]);
+                filter((imageKey) -> ElementLocker.lock(imageKey, ElementLock.LockMode.TRY_LOCK)).
+                toArray((imageKey) -> new String[imageKey]);
 
             if (isNotEmpty(targetImageKeys)) {
                 try {
@@ -688,7 +693,7 @@ public final class ImageConverter implements IImageConverter {
                 } catch (FileItemException e) {
                     throw new ImageConverterException("IC error while removing image " + targetImageKeys.length + " keys", e);
                 } finally {
-                    Arrays.asList(targetImageKeys).forEach(p -> ElementLocker.unlock(p));
+                    Arrays.asList(targetImageKeys).forEach(p -> ElementLocker.unlock(p, ElementLock.UnlockMode.STANDARD));
                 }
             }
         }
@@ -700,9 +705,13 @@ public final class ImageConverter implements IImageConverter {
     private static void implFinishRequest(@NonNull final RequestType requestType, final long requestStartTime, @NonNull final ImageConverterStatus imageConverterStatus) {
         final long requestDuration = System.currentTimeMillis() - requestStartTime;
 
-        implTrace(new StringBuilder("IC request type ").
-            append(requestType.name()).
-            append(" finished in ").append(requestDuration).append(" ms").toString());
+        if (LOG.isTraceEnabled()) {
+            implTrace(ImageConverterUtils.STR_BUILDER().
+                append("IC request type ").
+                append(requestType.name()).
+                append(" finished in ").
+                append(requestDuration).append(" ms").toString());
+        }
 
         ImageConverterUtils.IC_MONITOR.incrementRequests(requestType, requestDuration, imageConverterStatus);
     }
@@ -734,13 +743,10 @@ public final class ImageConverter implements IImageConverter {
      * @param traceMsg
      * @param context
      */
-    private static void implTrace(final String traceMsg, final String... context) {
-    	// TODO
-        if (LOG.isTraceEnabled() && (null != traceMsg)) {
-            LOG.trace(isNotEmpty(context) ?
-                new StringBuilder(traceMsg).append( "(Context: ").append(context[0]).append(")").toString() :
-                    traceMsg);
-        }
+    private static void implTrace(@NonNull final String traceMsg, final String... context) {
+        LOG.trace(isNotEmpty(context) ?
+            ImageConverterUtils.STR_BUILDER().append(traceMsg).append( "(Context: ").append(context[0]).append(")").toString() :
+                traceMsg);
     }
 
     // - Members ---------------------------------------------------------------
@@ -751,9 +757,9 @@ public final class ImageConverter implements IImageConverter {
 
     final private ImageFormat[] m_imageFormats;
 
-    final private ImageConverterQueue m_imageConversionQueue;
+    final private ImageConverterQueue m_queue;
 
     final private ImageConverterCache m_keyManager;
 
-    final private AtomicBoolean m_terminated = new AtomicBoolean(false);
+    final private AtomicBoolean m_running = new AtomicBoolean(true);
 }
