@@ -79,7 +79,6 @@ import com.openexchange.imageconverter.api.IMetadata;
 import com.openexchange.imageconverter.api.IMetadataReader;
 import com.openexchange.imageconverter.api.ImageConverterException;
 import com.openexchange.imageconverter.api.ImageFormat;
-import com.openexchange.imagetransformation.ScaleType;
 
 /**
  * {@link ImageConverterUtils}
@@ -167,6 +166,13 @@ public class ImageConverterUtils {
         IC_MONITOR = new ImageConverterMonitoring(IC = imageConverter);
     }
 
+    /**
+     * @return
+     */
+    public  static StringBuilder STR_BUILDER() {
+        return new StringBuilder(256);
+    }
+
     /**
      * @param availableFormats
      * @param requestFormat
@@ -194,11 +200,9 @@ public class ImageConverterUtils {
             }
 
             // iterate over all left entries within the imageFormatList
-            // and add all entries, whose to be tested parameters,
-            // defined in the test bit set, match the equivalent
-            // requestFormat parameters;
-            // leave the loop, if the candidate list contains at least
-            // one entry;
+            // and add all entries, whose to be tested parameters, defined
+            // in the test bit set, match the equivalent requestFormat parameters;
+            // leave the loop, if the candidate list contains at least one entry;
             // calling #implCreateImageFormatCandidateList with an empty
             // test set adds all entries from the current imageFormatList
             do {
@@ -246,12 +250,12 @@ public class ImageConverterUtils {
                 ret = imageFormats.get(imageFormats.size() - 1);
 
                 // this should not happen at all, if a valid ImageFormat list is provided
-                LOG.error(new StringBuilder("IC found no best matching image format for requested format, using target format: ").
+                LOG.error(STR_BUILDER().append("IC found no best matching image format for requested format, using target format: ").
                     append(requestFormat.getFormatString()).append(" => ").append(ret.getFormatString()).toString());
             }
 
             if (trace) {
-                LOG.trace(new StringBuilder("IC found best matching image format for requested format: ").
+                LOG.trace(STR_BUILDER().append("IC found best matching image format for requested format: ").
                     append(requestFormat.getFormatString()).append(" => ").append(ret.getFormatString()).toString());
             }
         } else if (LOG.isWarnEnabled()) {
@@ -275,7 +279,7 @@ public class ImageConverterUtils {
      * @return
      */
     public static String getIM4JOutput(@NonNull File outputFile, @NonNull final ImageFormat imageFormat) {
-        return new StringBuilder(imageFormat.getFormatShortName()).append(':').append(outputFile.getAbsolutePath()).toString();
+        return STR_BUILDER().append(imageFormat.getFormatShortName()).append(':').append(outputFile.getAbsolutePath()).toString();
     }
 
     /**
@@ -357,9 +361,9 @@ public class ImageConverterUtils {
      * @throws Exception
      */
     public static boolean shouldUseReferenceFormat(@NonNull final Dimension imageDimension, @NonNull final ImageFormat targetFormat) {
-        return ((targetFormat.isAutoRotate() == true) &&
-            (targetFormat.getScaleType() == ScaleType.CONTAIN) &&
-            targetFormat.isShrinkOnly() &&
+        // reference formats are possible for all different scaling types;
+        // autoRotate=true and shrinkOnly=true flags are mandatory in order to use reference formats
+        return ((targetFormat.isAutoRotate() == true) && targetFormat.isShrinkOnly() &&
             (compare(getResultingImageDimension(imageDimension, targetFormat), imageDimension) >= 0));
     }
 
@@ -423,7 +427,7 @@ public class ImageConverterUtils {
                         try (final InputStream resultInputStm = fileReadAcess.getInputStream()) {
                             if (null != resultInputStm) {
                                 final BufferedReader reader = new BufferedReader(new InputStreamReader(resultInputStm, "UTF-8"));
-                                StringBuilder jsonStrBuilder = new StringBuilder();
+                                StringBuilder jsonStrBuilder = STR_BUILDER();
                                 String readStr = null;
 
                                 while (null != (readStr = reader.readLine())) {
@@ -468,11 +472,10 @@ public class ImageConverterUtils {
             @NonNull final ImageFormat curImageFormat = iter.next();
 
             if (testParamSet.isEmpty() ||
-                (testParamSet.get(TEST_AUTOROTATE) && (curImageFormat.isAutoRotate() == testImageFormat.isAutoRotate())) &&
-                (testParamSet.get(TEST_SCALETYPE) && (curImageFormat.getScaleType().equals(testImageFormat.getScaleType())) &&
-                (testParamSet.get(TEST_SHRINKONLY) && (curImageFormat.isShrinkOnly() == testImageFormat.isShrinkOnly())) &&
-                (testParamSet.get(TEST_FORMATSHORTNAME) &&
-                 (isAutoFormat || curImageFormat.getFormatShortName().equals(testImageFormat.getFormatShortName()))))) {
+                (!testParamSet.get(TEST_AUTOROTATE) || (curImageFormat.isAutoRotate() == testImageFormat.isAutoRotate())) &&
+                (!testParamSet.get(TEST_SCALETYPE) || (curImageFormat.getScaleType().equals(testImageFormat.getScaleType())) &&
+                (!testParamSet.get(TEST_SHRINKONLY) || (curImageFormat.isShrinkOnly() == testImageFormat.isShrinkOnly())) &&
+                (!testParamSet.get(TEST_FORMATSHORTNAME) || isAutoFormat || curImageFormat.getFormatShortName().equals(testImageFormat.getFormatShortName())))) {
 
                 // if all important attributes match, move format to candidate list
                 candidateSet.add(curImageFormat);
